==> data-miner-manager-cl-1.1.0-20170306.115153-1-sources.jar: org/gcube/data/analysis/dataminermanagercl/shared/parameters/FileParameter.java <==
/**
 * 
 */
package org.gcube.data.analysis.dataminermanagercl.shared.parameters;

import java.util.ArrayList;

/**
 * 
 * @author Giancarlo Panichi email: <a
 *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
 *
 */
public class FileParameter extends Parameter {

	private static final long serialVersionUID = -2967577990287112937L;
	private String defaultMimeType;
	private ArrayList<String> supportedMimeTypes;

	/**
	 * 
	 */
	public FileParameter() {
		super();
		this.typology = ParameterType.FILE;
	}

	/**
	 * 
	 * @param name
	 * @param description
	 * @param fileName
	 * @param mimeType
	 */
	public FileParameter(String name, String description,
			String defaultMimeType, ArrayList<String> supportedMimeTypes) {
		super(name, ParameterType.FILE, description);
		this.defaultMimeType = defaultMimeType;
		this.supportedMimeTypes = supportedMimeTypes;
	}

	public String getDefaultMimeType() {
		return defaultMimeType;
	}

	public void setDefaultMimeType(String defaultMimeType) {
		this.defaultMimeType = defaultMimeType;
	}

	public ArrayList<String> getSupportedMimeTypes() {
		return supportedMimeTypes;
	}

	public void setSupportedMimeTypes(ArrayList<String> supportedMimeTypes) {
		this.supportedMimeTypes = supportedMimeTypes;
	}

	@Override
	public String toString() {
		return "FileParameter [value=" + value + ", defaultMimeType="
				+ defaultMimeType + ", supportedMimeTypes="
				+ supportedMimeTypes + ", name=" + name + ", description="
				+ description + ", typology=" + typology + "]";
	}

}

==> data-miner-manager-cl-1.3.0-4.11.1-148453-sources.jar: org/gcube/data/analysis/dataminermanagercl/shared/parameters/FileParameter.java <==
/**
 * 
 */
package org.gcube.data.analysis.dataminermanagercl.shared.parameters;

import java.util.ArrayList;

/**
 * 
 * @author Giancarlo Panichi
 *
 *
 */
public class FileParameter extends Parameter {

	private static final long serialVersionUID = -2967577990287112937L;
	private String defaultMimeType;
	private ArrayList<String> supportedMimeTypes;

	/**
	 * 
	 */
	public FileParameter() {
		super();
		this.typology = ParameterType.FILE;
	}

	/**
	 * 
	 * @param name
	 *            name
	 * @param description
	 *            description
	 * @param defaultMimeType
	 *            default mime type
	 * @param supportedMimeTypes
	 *            supported mime type
	 */
	public FileParameter(String name, String description, String defaultMimeType,
			ArrayList<String> supportedMimeTypes) {
		super(name, ParameterType.FILE, description);
		this.defaultMimeType = defaultMimeType;
		this.supportedMimeTypes = supportedMimeTypes;
	}

	public String getDefaultMimeType() {
		return defaultMimeType;
	}

	public void setDefaultMimeType(String defaultMimeType) {
		this.defaultMimeType = defaultMimeType;
	}

	public ArrayList<String> getSupportedMimeTypes() {
		return supportedMimeTypes;
	}

	public void setSupportedMimeTypes(ArrayList<String> supportedMimeTypes) {
		this.supportedMimeTypes = supportedMimeTypes;
	}

	@Override
	public String toString() {
		return "FileParameter [value=" + value + ", defaultMimeType=" + defaultMimeType + ", supportedMimeTypes="
				+ supportedMimeTypes + ", name=" + name + ", description=" + description + ", typology=" + typology
				+ "]";
	}

}
